@@ -20,11 +20,8 @@ function being called. Check the function signature of documentation
 to determine how a line will be interpreted.
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
-
-import numpy
-
-from pyrr import vector
-from pyrr.utils import all_parameters_as_numpy_arrays, parameters_as_numpy_arrays
+import numpy as np
+from .utils import all_parameters_as_numpy_arrays, parameters_as_numpy_arrays
 
 
 class index:
@@ -41,7 +38,7 @@ def create_zeros(dtype=None):
     :rtype: numpy.array
     :return: A line with both start and end points at (0,0,0).
     """
-    return numpy.zeros((2,3), dtype=dtype)
+    return np.zeros((2,3), dtype=dtype)
 
 def create_from_points(v1, v2, dtype=None):
     """Creates a line from 2 vectors.
@@ -53,7 +50,7 @@ def create_from_points(v1, v2, dtype=None):
     :rtype: numpy.array
     :return: A line extending from v1 to v2.
     """
-    return numpy.array([v1, v2], dtype=dtype)
+    return np.array([v1, v2], dtype=dtype)
 
 @all_parameters_as_numpy_arrays
 def create_from_ray(ray):
@@ -68,7 +65,7 @@ def create_from_ray(ray):
     """
     # convert ray relative direction to absolute
     # position
-    return numpy.array([ray[0], ray[0] + ray[1]], dtype=ray.dtype)
+    return np.array([ray[0], ray[0] + ray[1]], dtype=ray.dtype)
 
 @all_parameters_as_numpy_arrays
 def start(line):
