@@ -19,7 +19,7 @@ class index:
     size = 1
 
 
-def create(x=0, y=0, width=1, height=1, dtype=None):
+def create(x=0., y=0., width=1., height=1., dtype=None):
     """Creates a rectangle from the specified position and sizes.
 
     This function will interpret the values literally. A negative width
@@ -31,8 +31,7 @@ def create(x=0, y=0, width=1, height=1, dtype=None):
     return np.array([[x, y], [width, height]], dtype=dtype)
 
 def create_zeros(dtype=None):
-    # use np.array instead of np.zeroes as np.zeros defaults to dtype=np.float
-    return np.array(((0,0),(0,0)), dtype=dtype)
+    return np.zeros((2,2), dtype=dtype)
 
 def create_from_bounds(left, right, bottom, top, dtype=None):
     """Creates a rectangle from the specified boundaries.
